@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2025 Tencent. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -95,6 +95,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CancelOnlineDDLJob(self, request):
+        """取消 Online DDL 任务
+
+        :param request: Request instance for CancelOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.CancelOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.CancelOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CancelOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.CancelOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CloneAccount(self, request):
         """本接口（CloneAccount）用于克隆实例账户。
 
@@ -926,6 +949,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeInstanceSSLAttributes(self, request):
+        """本接口（DescribeInstanceSSLAttributes）用于拉取实例SSL认证属性
+
+        :param request: Request instance for DescribeInstanceSSLAttributes.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeInstanceSSLAttributesRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeInstanceSSLAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeInstanceSSLAttributes", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeInstanceSSLAttributesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeLogFileRetentionPeriod(self, request):
         """本接口(DescribeLogFileRetentionPeriod)用于查看数据库备份日志的备份天数的设置情况。
 
@@ -949,6 +995,29 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeOnlineDDLJob(self, request):
+        """查询Online DDL 任务详情
+
+        :param request: Request instance for DescribeOnlineDDLJob.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeOnlineDDLJobRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeOnlineDDLJobResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeOnlineDDLJob", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeOnlineDDLJobResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeOrders(self, request):
         """本接口（DescribeOrders）用于查询分布式数据库订单信息。传入订单ID来查询订单关联的分布式数据库实例，和对应的任务流程ID。
 
@@ -972,6 +1041,32 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeProcessList(self, request):
+        """本接口 (DescribeProcessList) 用于查询当前正在运行的线程（连接/查询）信息。
+
+        - 可以根据客户端IP，DB，执行时间等信息来查询实例正在运行的线程信息。过滤信息详细请见过滤器Filter。
+        - 如果参数为空，返回当前用户一定数量（Limit所指定的数量，默认为20）的线程信息。
+
+        :param request: Request instance for DescribeProcessList.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.DescribeProcessListRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.DescribeProcessListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeProcessList", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeProcessListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeProjectSecurityGroups(self, request):
         """本接口（DescribeProjectSecurityGroups）用于查询项目安全组信息
 
@@ -1556,6 +1651,52 @@ class DcdbClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def ModifyInstanceProtectedProperty(self, request):
+        """该接口用于修改实例的保护属性
+
+        :param request: Request instance for ModifyInstanceProtectedProperty.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.ModifyInstanceProtectedPropertyRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.ModifyInstanceProtectedPropertyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceProtectedProperty", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceProtectedPropertyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyInstanceSSLAttributes(self, request):
+        """本接口  （ModifyInstanceSSLAttributes）用于修改实例SSL认证功能属性
+
+        :param request: Request instance for ModifyInstanceSSLAttributes.
+        :type request: :class:`tencentcloud.dcdb.v20180411.models.ModifyInstanceSSLAttributesRequest`
+        :rtype: :class:`tencentcloud.dcdb.v20180411.models.ModifyInstanceSSLAttributesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyInstanceSSLAttributes", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyInstanceSSLAttributesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyInstanceVip(self, request):
         """本接口（ModifyInstanceVip）用于修改实例Vip
 
